package crm

import (
	"github.com/gin-gonic/gin"
	"server/dao/crm"
	"server/global"
	"server/model/common/response"
	"strconv"
)

type ProgressApi struct{}

func (pa *ProgressApi) QueryProgressByCustomerId(c *gin.Context) {
	id := c.Query("id")
	customerId, err := strconv.Atoi(id)
	if err != nil {
		response.FailWithMessage("参数错误", c)
		global.GVA_LOG.Error("QueryProgressByCustomerId ====== " + err.Error())
		return
	}
	progress, err := progressService.QueryProgressByCustomerId(customerId)
	if err != nil {
		response.FailWithMessage("查询失败", c)
		global.GVA_LOG.Error("QueryProgressByCustomerId ====== " + err.Error())
		return
	}
	response.OkWithData(progress, c)
}

func (pa *ProgressApi) CreateProgress(c *gin.Context) {
	var progress crm.Progress
	err := c.ShouldBindJSON(&progress)
	if err != nil {
		response.FailWithMessage("参数错误", c)
		global.GVA_LOG.Error("CreateProgress ====== " + err.Error())
		return
	}
	err = progressService.CreateProgress(progress)
	if err != nil {
		response.FailWithMessage("创建失败", c)
		global.GVA_LOG.Error("CreateProgress ====== " + err.Error())
		return
	}
	response.OkWithMessage("创建成功", c)
}

func (pa *ProgressApi) UpdateProgress(c *gin.Context) {
	var progress crm.Progress
	err := c.ShouldBindJSON(&progress)
	if err != nil {
		response.FailWithMessage("参数错误", c)
		global.GVA_LOG.Error("UpdateProgress ====== " + err.Error())
		return
	}
	err = progressService.UpdateProgress(progress)
	if err != nil {
		response.FailWithMessage("更新失败", c)
		global.GVA_LOG.Error("UpdateProgress ====== " + err.Error())
		return
	}
	response.OkWithMessage("更新成功", c)
}

func (pa *ProgressApi) DeleteProgress(c *gin.Context) {
	id := c.Query("id")
	progressId, err := strconv.Atoi(id)
	if err != nil {
		response.FailWithMessage("参数错误", c)
		global.GVA_LOG.Error("DeleteProgress ====== " + err.Error())
		return
	}
	err = progressService.DeleteProgress(progressId)
	if err != nil {
		response.FailWithMessage("删除失败", c)
		global.GVA_LOG.Error("DeleteProgress ====== " + err.Error())
		return
	}
	response.OkWithMessage("删除成功", c)
}
