package storehouse

import (
	"github.com/gin-gonic/gin"
	"server/dao"
	"server/global"
	"server/model/common/response"
)

type CommodityGenreApi struct{}

func (cga *CommodityGenreApi) QueryAllCommodityGenre(c *gin.Context) {
	commodityGenres, err := commodityGenreService.QueryAllCommodityGenre()
	if err != nil {
		response.FailWithMessage("查询失败", c)
		global.GVA_LOG.Error("QueryAllCommodityGenre ======= " + err.Error())
		return
	}
	response.OkWithData(commodityGenres, c)
}

func (cga *CommodityGenreApi) CreateCommodityGenre(c *gin.Context) {
	var commodityGenre dao.CommodityGenre
	err := c.ShouldBindJSON(&commodityGenre)
	if err != nil {
		response.FailWithMessage("参数解析失败", c)
		global.GVA_LOG.Error("CreateCommodityGenre ======= " + err.Error())
		return
	}
	err = commodityGenreService.CreateCommodityGenre(commodityGenre)
	if err != nil {
		response.FailWithMessage("创建失败", c)
		global.GVA_LOG.Error("CreateCommodityGenre ======= " + err.Error())
		return
	}
	response.OkWithMessage("创建成功", c)
}

func (cga *CommodityGenreApi) UpdateCommodityGenre(c *gin.Context) {
	var commodityGenre dao.CommodityGenre
	err := c.ShouldBindJSON(&commodityGenre)
	if err != nil {
		response.FailWithMessage("参数解析失败", c)
		global.GVA_LOG.Error("UpdateCommodityGenre ======= " + err.Error())
		return
	}
	err = commodityGenreService.UpdateCommodityGenre(commodityGenre)
	if err != nil {
		response.FailWithMessage("更新失败", c)
		global.GVA_LOG.Error("UpdateCommodityGenre ======= " + err.Error())
		return
	}
	response.OkWithMessage("更新成功", c)
}

func (cga *CommodityGenreApi) DeleteCommodityGenre(c *gin.Context) {
	var commodityGenre dao.CommodityGenre
	err := c.ShouldBindJSON(&commodityGenre)
	if err != nil {
		response.FailWithMessage("参数解析失败", c)
		global.GVA_LOG.Error("DeleteCommodityGenre ======= " + err.Error())
		return
	}
	err = commodityGenreService.DeleteCommodityGenre(commodityGenre)
	if err != nil {
		response.FailWithMessage("删除失败", c)
		global.GVA_LOG.Error("DeleteCommodityGenre ======= " + err.Error())
		return
	}
	response.OkWithMessage("删除成功", c)
}
