package storehouse

import (
	"github.com/gin-gonic/gin"
	"server/dao"
	"server/global"
	"server/model/common/request"
	"server/model/common/response"
)

type PlaceApi struct{}

func (pa *PlaceApi) QueryAllPlace(c *gin.Context) {
	places, err := placeService.QueryAllPlaces()
	if err != nil {
		response.FailWithMessage("查询失败", c)
		global.GVA_LOG.Error("QueryAllPlace ======= " + err.Error())
		return
	}
	response.OkWithData(places, c)
}

func (pa *PlaceApi) QueryPlaceList(c *gin.Context) {
	var info request.SearchPlace
	err := c.ShouldBindJSON(&info)
	if err != nil {
		response.FailWithMessage("参数解析失败", c)
		global.GVA_LOG.Error("QueryPlaceList ======= " + err.Error())
		return
	}
	list, total, err := placeService.QueryPlaceList(info)
	if err != nil {
		response.FailWithMessage("查询失败", c)
		global.GVA_LOG.Error("QueryPlaceList ======= " + err.Error())
		return
	}
	response.OkWithDetailed(response.PageResult{
		List:     list,
		Total:    total,
		Page:     info.PageInfo.Page,
		PageSize: info.PageInfo.PageSize,
	}, "获取成功", c)
}

func (pa *PlaceApi) CreatePlace(c *gin.Context) {
	var place dao.Place
	err := c.ShouldBindJSON(&place)
	if err != nil {
		response.FailWithMessage("参数解析失败", c)
		global.GVA_LOG.Error("CreatePlace ======= " + err.Error())
		return
	}
	err = placeService.CreatePlace(place)
	if err != nil {
		response.FailWithMessage("创建失败", c)
		global.GVA_LOG.Error("CreatePlace ======= " + err.Error())
		return
	}
	response.OkWithMessage("创建成功", c)
}

func (pa *PlaceApi) UpdatePlace(c *gin.Context) {
	var place dao.Place
	err := c.ShouldBindJSON(&place)
	if err != nil {
		response.FailWithMessage("参数解析失败", c)
		global.GVA_LOG.Error("UpdatePlace ======= " + err.Error())
		return
	}
	err = placeService.UpdatePlace(place)
	if err != nil {
		response.FailWithMessage("更新失败", c)
		global.GVA_LOG.Error("UpdatePlace ======= " + err.Error())
		return
	}
	response.OkWithMessage("更新成功", c)
}

func (pa *PlaceApi) SwitchPlace(c *gin.Context) {
	var place dao.Place
	err := c.ShouldBindJSON(&place)
	if err != nil {
		response.FailWithMessage("参数解析失败", c)
		global.GVA_LOG.Error("SwitchPlace ======= " + err.Error())
		return
	}
	err = placeService.SwitchPlace(place)
	if err != nil {
		response.FailWithMessage("切换失败", c)
		global.GVA_LOG.Error("SwitchPlace ======= " + err.Error())
		return
	}
	response.OkWithMessage("切换成功", c)
}

func (pa *PlaceApi) DeletePlace(c *gin.Context) {
	var place dao.Place
	err := c.ShouldBindJSON(&place)
	if err != nil {
		response.FailWithMessage("参数解析失败", c)
		global.GVA_LOG.Error("DeletePlace ======= " + err.Error())
		return
	}
	err = placeService.DeletePlace(place)
	if err != nil {
		response.FailWithMessage("删除失败", c)
		global.GVA_LOG.Error("DeletePlace ======= " + err.Error())
		return
	}
	response.OkWithMessage("删除成功", c)
}
