package storehouse

import (
	"github.com/gin-gonic/gin"
	"server/dao"
	"server/global"
	"server/model/common/request"
	"server/model/common/response"
)

type StorageAreaApi struct{}

func (ssa *StorageAreaApi) QueryAllStorageAreas(c *gin.Context) {
	area, err := storageAreaService.QueryAllStorageArea()
	if err != nil {
		response.FailWithMessage("查询失败", c)
		global.GVA_LOG.Error("QueryAllStorageAreas ====== " + err.Error())
		return
	}
	response.OkWithData(area, c)
}

func (ssa *StorageAreaApi) QueryStorageAreaList(c *gin.Context) {
	var info request.SearchStorageArea
	err := c.ShouldBindJSON(&info)
	if err != nil {
		response.FailWithMessage("参数解析失败", c)
		global.GVA_LOG.Error("QueryPlaceList ======= " + err.Error())
		return
	}
	list, total, err := storageAreaService.QueryStorageAreaList(info)
	if err != nil {
		response.FailWithMessage("查询失败", c)
		global.GVA_LOG.Error("QueryPlaceList ======= " + err.Error())
		return
	}
	response.OkWithDetailed(response.PageResult{
		List:     list,
		Total:    total,
		Page:     info.PageInfo.Page,
		PageSize: info.PageInfo.PageSize,
	}, "获取成功", c)
}

func (ssa *StorageAreaApi) CreateStorageArea(c *gin.Context) {
	var area dao.StorageArea
	err := c.ShouldBindJSON(&area)
	if err != nil {
		response.FailWithMessage("参数解析失败", c)
		global.GVA_LOG.Error("CreateStorageArea ====== " + err.Error())
		return
	}
	err = storageAreaService.CreateStorageArea(area)
	if err != nil {
		response.FailWithMessage("创建失败", c)
		global.GVA_LOG.Error("CreateStorageArea ====== " + err.Error())
		return
	}
	response.OkWithMessage("创建成功", c)
}

func (ssa *StorageAreaApi) UpdateStorageArea(c *gin.Context) {
	var area dao.StorageArea
	err := c.ShouldBindJSON(&area)
	if err != nil {
		response.FailWithMessage("参数解析失败", c)
		global.GVA_LOG.Error("UpdateStorageArea ====== " + err.Error())
		return
	}
	err = storageAreaService.UpdateStorageArea(area)
	if err != nil {
		response.FailWithMessage("修改失败", c)
		global.GVA_LOG.Error("UpdateStorageArea ====== " + err.Error())
		return
	}
	response.OkWithMessage("修改成功", c)
}

func (ssa *StorageAreaApi) SwitchStorageArea(c *gin.Context) {
	var area dao.StorageArea
	err := c.ShouldBindJSON(&area)
	if err != nil {
		response.FailWithMessage("参数解析失败", c)
		global.GVA_LOG.Error("SwitchStorageArea ====== " + err.Error())
		return
	}
	err = storageAreaService.SwitchStorageArea(area)
	if err != nil {
		response.FailWithMessage("切换状态失败", c)
		global.GVA_LOG.Error("SwitchStorageArea ====== " + err.Error())
		return
	}
	response.OkWithMessage("切换状态成功", c)
}

func (ssa *StorageAreaApi) DeleteStorageArea(c *gin.Context) {
	var area dao.StorageArea
	err := c.ShouldBindJSON(&area)
	if err != nil {
		response.FailWithMessage("参数解析失败", c)
		global.GVA_LOG.Error("DeleteStorageArea ====== " + err.Error())
		return
	}
	err = storageAreaService.DeleteStorageArea(area)
	if err != nil {
		response.FailWithMessage("删除失败", c)
		global.GVA_LOG.Error("DeleteStorageArea ====== " + err.Error())
		return
	}
	response.OkWithMessage("删除成功", c)
}
