package storehouse

import (
	"github.com/gin-gonic/gin"
	"server/dao"
	"server/global"
	"server/model/common/response"
)

type StorageAreaGenreApi struct{}

func (saga *StorageAreaGenreApi) QueryAllStorageAreaGenre(c *gin.Context) {
	genres, err := storageAreaGenreService.QueryAllStorageAreaGenres()
	if err != nil {
		response.FailWithMessage("查询失败", c)
		global.GVA_LOG.Error("QueryAllStorageAreaGenre ======= " + err.Error())
		return
	}
	response.OkWithData(genres, c)
}

func (saga *StorageAreaGenreApi) CreateStorageAreaGenre(c *gin.Context) {
	var genre dao.StorageAreaGenre
	err := c.ShouldBindJSON(&genre)
	if err != nil {
		response.FailWithMessage("参数错误", c)
		global.GVA_LOG.Error("CreateStorageAreaGenre ======= " + err.Error())
		return
	}
	err = storageAreaGenreService.CreateStorageAreaGenre(genre)
	if err != nil {
		response.FailWithMessage("创建失败", c)
		global.GVA_LOG.Error("CreateStorageAreaGenre ======= " + err.Error())
		return
	}
	response.OkWithMessage("创建成功", c)
}

func (saga *StorageAreaGenreApi) UpdateStorageAreaGenre(c *gin.Context) {
	var genre dao.StorageAreaGenre
	err := c.ShouldBindJSON(&genre)
	if err != nil {
		response.FailWithMessage("参数错误", c)
		global.GVA_LOG.Error("UpdateStorageAreaGenre ======= " + err.Error())
		return
	}
	err = storageAreaGenreService.UpdateStorageAreaGenre(genre)
	if err != nil {
		response.FailWithMessage("更新失败", c)
		global.GVA_LOG.Error("UpdateStorageAreaGenre ======= " + err.Error())
		return
	}
	response.OkWithMessage("更新成功", c)
}

func (saga *StorageAreaGenreApi) DeleteStorageAreaGenre(c *gin.Context) {
	var genre dao.StorageAreaGenre
	err := c.ShouldBindJSON(&genre)
	if err != nil {
		response.FailWithMessage("参数错误", c)
		global.GVA_LOG.Error("DeleteStorageAreaGenre ======= " + err.Error())
		return
	}
	err = storageAreaGenreService.DeleteStorageAreaGenre(genre)
	if err != nil {
		response.FailWithMessage("删除失败", c)
		global.GVA_LOG.Error("DeleteStorageAreaGenre ======= " + err.Error())
		return
	}
	response.OkWithMessage("删除成功", c)
}
