package storehouse

import (
	"github.com/gin-gonic/gin"
	"server/dao"
	"server/global"
	"server/model/common/request"
	"server/model/common/response"
)

type WarehouseApi struct{}

func (wa *WarehouseApi) QueryAllWarehouse(c *gin.Context) {
	warehouses, err := warehouseService.QueryAllWarehouse()
	if err != nil {
		response.FailWithMessage("查询失败", c)
		global.GVA_LOG.Error("QueryAllWarehouse ====== " + err.Error())
		return
	}
	response.OkWithData(warehouses, c)
}

func (wa *WarehouseApi) QueryWarehouseList(c *gin.Context) {
	var info request.SearchWarehouse
	err := c.ShouldBindJSON(&info)
	if err != nil {
		response.FailWithMessage("参数解析失败", c)
		global.GVA_LOG.Error("QueryWarehouseList ====== " + err.Error())
		return
	}
	list, total, err := warehouseService.QueryWarehouseList(info)
	if err != nil {
		response.FailWithMessage("查询失败", c)
		global.GVA_LOG.Error("QueryWarehouseList ====== " + err.Error())
		return
	}
	response.OkWithDetailed(response.PageResult{
		List:     list,
		Total:    total,
		Page:     info.PageInfo.Page,
		PageSize: info.PageInfo.PageSize,
	}, "获取成功", c)
}

func (wa *WarehouseApi) CreateWarehouse(c *gin.Context) {
	var warehouse dao.Warehouse
	err := c.ShouldBindJSON(&warehouse)
	if err != nil {
		response.FailWithMessage("参数解析失败", c)
		global.GVA_LOG.Error("CreateWarehouse ====== " + err.Error())
		return
	}
	err = warehouseService.CreateWarehouse(warehouse)
	if err != nil {
		response.FailWithMessage("创建失败", c)
		global.GVA_LOG.Error("CreateWarehouse ====== " + err.Error())
		return
	}
	response.OkWithMessage("创建成功", c)
}

func (wa *WarehouseApi) UpdateWarehouse(c *gin.Context) {
	var warehouse dao.Warehouse
	err := c.ShouldBindJSON(&warehouse)
	if err != nil {
		response.FailWithMessage("参数解析失败", c)
		global.GVA_LOG.Error("UpdateWarehouse ====== " + err.Error())
		return
	}
	err = warehouseService.UpdateWarehouse(warehouse)
	if err != nil {
		response.FailWithMessage("更新失败", c)
		global.GVA_LOG.Error("UpdateWarehouse ====== " + err.Error())
		return
	}
	response.OkWithMessage("更新成功", c)
}

func (wa *WarehouseApi) SwitchWarehouse(c *gin.Context) {
	var warehouse dao.Warehouse
	err := c.ShouldBindJSON(&warehouse)
	if err != nil {
		response.FailWithMessage("参数解析失败", c)
		global.GVA_LOG.Error("SwitchWarehouse ====== " + err.Error())
		return
	}
	err = warehouseService.SwitchWarehouse(warehouse)
	if err != nil {
		response.FailWithMessage("切换失败", c)
		global.GVA_LOG.Error("SwitchWarehouse ====== " + err.Error())
		return
	}
	response.OkWithMessage("切换成功", c)
}

func (wa *WarehouseApi) DeleteWarehouse(c *gin.Context) {
	var warehouse dao.Warehouse
	err := c.ShouldBindJSON(&warehouse)
	if err != nil {
		response.FailWithMessage("参数解析失败", c)
		global.GVA_LOG.Error("DeleteWarehouse ====== " + err.Error())
		return
	}
	err = warehouseService.DeleteWarehouse(warehouse)
	if err != nil {
		response.FailWithMessage("删除失败", c)
		global.GVA_LOG.Error("DeleteWarehouse ====== " + err.Error())
		return
	}
	response.OkWithMessage("删除成功", c)
}
